@@ -10,6 +10,8 @@
 #'
 #'@return Returns estimated median and quantile based credible limits for omega.
 #'
+#'@import TeachingDemos
+#'
 #'@examples
 #'
 #'\donttest{
@@ -57,10 +59,10 @@ bomega=function(K,mod,alpha,beta,CI){
   beta=0.4*alpha/0.6}
   if(am+bm==11){alpha=3.51
   beta=1.75}
-  ll=(1-CI)/2
-  ul=1-ll
-  out=round(qbeta(c(ll,0.5,ul),alpha+Lambda2,beta+Psi),4)
-  names(out)=c("LL","Median","UL")
-  out
+
+  out=round(c(qbeta(c(0.5),alpha+Lambda2,beta+Psi),
+              hpd(qbeta,shape1=alpha+Lambda2,shape2=beta+Psi,conf=CI)[1],
+              hpd(qbeta,shape1=alpha+Lambda2,shape2=beta+Psi,conf=CI)[2]),4)
+  names(out)=c("Median","LL","UL")
   return(out)
 }
