@@ -9,6 +9,10 @@
 #'@param CI Credible interval quantile, as a decimal (ie, for 95 percent, 0.95).
 #'@param items Number of test items.
 #'
+#'@import MCMCpack
+#'@import MASS
+#'@import TeachingDemos
+#'
 #'@return Returns estimated median and quantile based credible limits for reliability.
 #'
 #'@examples
@@ -36,8 +40,9 @@ brxx_ICC_general=function(WS,Resid,alpha,beta,CI,items){
   beta=1.75}
   ll=(1-CI)/2
   ul=1-ll
-  Out=round(qbeta(p=c(ll,0.5,ul),alpha+WS*items,beta+Resid*items),4)
-  names(Out)=c("LL","Median","UL")
-  Out
+  Out=round(c(qbeta(c(0.5),alpha+WS*items,beta+Resid*items),
+              hpd(qbeta,shape1=alpha+WS*items,shape2=beta+Resid*items,conf=CI)[1],
+              hpd(qbeta,shape1=alpha+WS*items,shape2=beta+Resid*items,conf=CI)[2]),4)
+  names(Out)=c("Median","LL","UL")
   return(Out)
 }
