@@ -9,6 +9,14 @@
 #'@param CI Credible interval quantile, as a decimal (ie, for 95 percent, 0.95).
 #'@param items Number of test items.
 #'
+#'@import MCMCpack
+#'@import MASS
+#'@import TeachingDemos
+#'
+#'@import MCMCpack
+#'@import MASS
+#'@import TeachingDemos
+#'
 #'@return Returns estimated median and quantile based credible limits for reliability.
 #'
 #'@examples
@@ -36,10 +44,9 @@ brxx_general=function(a,b,alpha,beta,CI,items){
   beta=0.4*alpha/0.6}
   if(am+bm==11){alpha=3.51
   beta=1.75}
-  ll=(1-CI)/2
-  ul=1-ll
-  Out=round(qbeta(p=c(ll,0.5,ul),alpha+a*items,beta+b*items),4)
-  names(Out)=c("LL","Median","UL")
-  Out
+  Out=round(c(qbeta(p=c(0.5),alpha+a*items,beta+b*items),
+              hpd(qbeta,shape1=alpha+a*items,shape2=beta+b*items,conf=CI)[1],
+              hpd(qbeta,shape1=alpha+a*items,shape2=beta+b*items,conf=CI)[2]),4)
+  names(Out)=c("Median","LL","UL")
   return(Out)
 }
